﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Xml.Linq;
using System.Text;
using System.Windows.Forms;
using System.Windows.Input;
using B3.PluginAPIKit;
using System.IO;

namespace OpenDocumentPlugin
{
	public class SecondPlugin : IPlugin
	{

		private IHost mHost;
		private bool mActivated;
		private INavContext mNav;
		private IEditorContext mEditorContext;

		void IPlugin.Execute()
		{
			mActivated = true;
			mNav = mHost.GetNavContext();
			mEditorContext = mHost.GetEditorContext();
			CreateToolBarAndRibbon();
		}

		public string GetAuthor()
		{
			return "Flare for Programmers";
		}

		public string GetDescription()
		{
			return "This is a plug-in to demonstrate OpenDocument.";
		}

		public string GetName()
		{
			return "Open Document";
		}

		public string GetVersion()
		{
			return "0.1";
		}

		public void Initialize(IHost host)
		{
			mHost = host;
		}

		public bool IsActivated
		{
			get { return mActivated; }
		}

		public void Stop()
		{
			MessageBox.Show(GetName() + " deactivated.");
			mHost.Dispose();
			mActivated = false;
		}

		private void CreateToolBarAndRibbon()
		{
			//ToolBar
			ICustomToolBar toolbar = mNav.CreateCustomToolBar("Open Document");
			toolbar.AddButton("Open", new ButtonCommand(mEditorContext));

			//Ribbon
			IRibbon ribbon = mNav.GetRibbon();
			IRibbonTab tab = ribbon.AddNewRibbonTab("Open Document");
			IRibbonGroup group = tab.AddNewRibbonGroup("Open Document");
			group.AddRibbonButton("Open", new ButtonCommand(mEditorContext),
				null, null, RibbonIconSize.Collapsed, null, null);
		}

		public static void buttonActions(IEditorContext pEditorContext)
		{
			OpenFileDialog openFileDialogTopic = new OpenFileDialog();

			openFileDialogTopic.InitialDirectory = "C:\\";
			openFileDialogTopic.Filter = "htm files (*.htm)|*.htm";
			openFileDialogTopic.FilterIndex = 2;
			openFileDialogTopic.RestoreDirectory = true;

			if (openFileDialogTopic.ShowDialog() == DialogResult.OK)
			{
				pEditorContext.OpenDocument(openFileDialogTopic.FileName,
					EditorView.Text);
			}

		}


		private class ButtonCommand : ICommand
		{
			private IEditorContext passEditorContext;

			public ButtonCommand(IEditorContext pEditorContext)
			{
				passEditorContext = pEditorContext;
			}

			public bool CanExecute(object parameter)
			{
				return true;
			}

			public event EventHandler CanExecuteChanged;

			public void Execute(object parameter)
			{
				buttonActions(passEditorContext);
			}
		}
	}
}
